<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Teknisa\EST\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class Est32200ProdutosSemMovimentacao extends TeknisaCrud {

    protected $Est32200Service;
    protected $reportService;
    protected $dataSourceName = "posestatu_produto";
    protected $environment;
    protected $parameterBagColumns = [
    	"CDFILIAL",
		"CDALMOXARIFE",
		"CDLOCALESTOQ",
		"CDPRODINI",
		"CDPRODFIN",
		"ORDENACAO",
		"IDTIPOMOVI",
		"DTLIMITE",
		"NRTPARVPROD",
		"NRARVOREPROD"
	];

	public function __construct($crudService, $parameterBag, $reportService, $Est32200Service, $environment) {
		parent::__construct($crudService, $parameterBag);
		$this->Est32200Service = $Est32200Service;
		$this->reportService = $reportService;
		$this->environment = $environment;
	}

	public function find(DTO\Request\Filter $request, DTO\Response $response) {
		parent::find($request, $response);
		$dataSets = $response->getDataSets();
		//consertar para quando não voltar nada
		if(!empty($dataSet[0])){
			$row = $dataSets[0]->getRows();
			try {
				$newResponseRow = $this->Est32200Service->buildDataSet($row);
				$newDataSet = $this->buildDataSet($newResponseRow);
				$response->setDataSets(array($newDataSet));
			} catch (\Exception $e){
				$response->setError(new Error($e->getMessage(), 500));
			}
		}


	}

	public function buildDataSet($row) {
		$dataSet = new DataSet($this->dataSourceName, $row);
		return $dataSet;
	}

	public function geraReport(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		
		$row["NRORG"] = $this->environment->getNrOrgTrab();

        $parameterMapping = array(
            "NRORG" => "NRORG",
			"CDFILIAL" => "CDFILIAL",
			"CDALMOXARIFE" => "CDALMOXARIFE",
			"CDLOCALESTOQ" => "CDLOCALESTOQ",
			"CDPRODINI" => "CDPRODINI",
			"CDPRODFIN" => "CDPRODFIM",
			"DTLIMITE" => "DTLIMITE",
			"IDTIPOMOVI" => "IDTIPOMOVI",
			"ORDENACAO" => "ORDENACAO",
			"NRDIAS" => "NRDIAS",
			"DTPROCESSA" => "DATAPROCESSA",
			"NRTPARVPROD" => "NRTPARVPROD",
			"NRARVOREPROD" => "NRARVOREPROD"
    	);
        try {
            $dadosParaRelatorio = $this->Est32200Service->buildParametersByRelatorio($row, $parameterMapping);
            $reportName = $dadosParaRelatorio['ReportName'];
            $parametersRow = $dadosParaRelatorio['ParametersRow'];
            $parametersRow["__format"] = $row["__FORMAT"];
            $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow);

            $response->addMessage(new DTO\Response\Message($birtURL));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage() , 500));
        }
	}

}